==> dcmtk-docs-3.6.9-3-x86_64.pkg.tar.zst: usr/share/doc/dcmtk/html/search/groups_f.js <==
var searchData=
[
  ['the_20update_20add_20functions_0',['Position helper functions (use in conjunction with the update&amp;add functions)',['../group__xmlPosition.html',1,'']]],
  ['the_20xml_20parser_1',['The XML parser',['../group__XMLParserGeneral.html',1,'']]],
  ['the_20xmlnode_20structure_2',['the XMLNode structure',['../group__xmlModify.html',1,'Create or Update the XMLNode structure'],['../group__navigate.html',1,'Navigate the XMLNode structure']]],
  ['thread_20concept_3',['SCP Thread Concept',['../group__SCPThread__Concept.html',1,'']]],
  ['to_20an_20xmlnode_20structure_20and_20rendering_20xmlnode_20s_20to_20files_20string_4',['Parsing XML files/strings to an XMLNode structure and Rendering XMLNode&apos;s to files/string.',['../group__conversions.html',1,'']]],
  ['to_20create_20xml_20files_20using_20printf_20fprintf_20cout_20functions_5',['Helper class to create XML files using &quot;printf&quot;, &quot;fprintf&quot;, &quot;cout&quot;,... functions.',['../group__ToXMLStringTool.html',1,'']]],
  ['to_20files_20string_6',['Parsing XML files/strings to an XMLNode structure and Rendering XMLNode&apos;s to files/string.',['../group__conversions.html',1,'']]],
  ['to_20include_20binary_20data_20inside_20xml_20strings_20using_20base64_20encoding_7',['Helper class to include binary data inside XML strings using &quot;Base64 encoding&quot;.',['../group__XMLParserBase64Tool.html',1,'']]],
  ['tools_20for_20in_20place_20construction_8',['Tools for in-place construction',['../group__OFin__place__helpers.html',1,'']]]
];

==> dcmtk-docs-3.7.0-1-x86_64.pkg.tar.zst: usr/share/doc/dcmtk/html/search/groups_f.js <==
var searchData=
[
  ['the_20update_20add_20functions_0',['Position helper functions (use in conjunction with the update&amp;amp;add functions)',['../group__xmlPosition.html',1,'']]],
  ['the_20xml_20parser_1',['The XML parser',['../group__XMLParserGeneral.html',1,'']]],
  ['the_20xmlnode_20structure_2',['the XMLNode structure',['../group__xmlModify.html',1,'Create or Update the XMLNode structure'],['../group__navigate.html',1,'Navigate the XMLNode structure']]],
  ['thread_20concept_3',['SCP Thread Concept',['../group__SCPThread__Concept.html',1,'']]],
  ['to_20an_20xmlnode_20structure_20and_20rendering_20xmlnode_20s_20to_20files_20string_4',['Parsing XML files/strings to an XMLNode structure and Rendering XMLNode&apos;s to files/string.',['../group__conversions.html',1,'']]],
  ['to_20create_20xml_20files_20using_20printf_20fprintf_20cout_20functions_5',['Helper class to create XML files using &quot;printf&quot;, &quot;fprintf&quot;, &quot;cout&quot;,... functions.',['../group__ToXMLStringTool.html',1,'']]],
  ['to_20files_20string_6',['Parsing XML files/strings to an XMLNode structure and Rendering XMLNode&apos;s to files/string.',['../group__conversions.html',1,'']]],
  ['to_20include_20binary_20data_20inside_20xml_20strings_20using_20base64_20encoding_7',['Helper class to include binary data inside XML strings using &quot;Base64 encoding&quot;.',['../group__XMLParserBase64Tool.html',1,'']]],
  ['tools_20for_20in_20place_20construction_8',['Tools for in-place construction',['../group__OFin__place__helpers.html',1,'']]]
];
